/*
 * Copyright 2007 ETH Zuerich, CISD
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ch.systemsx.cisd.ant.common;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * 
 *
 * @author felmer
 */
public class RecursiveProjectTraverser
{
    public static void traverse(IProjectHandler projectHandler)
    {
        traverse(projectHandler, new HashSet<EclipseClasspathEntry>());
    }
    
    private static void traverse(IProjectHandler projectHandler, Set<EclipseClasspathEntry> visitedEntries)
    {
        projectHandler.handleOnEntering();
        IEclipseClasspathLocation loc = projectHandler.createLocation();
        if (loc != null)
        {
            List<EclipseClasspathEntry> entries = EclipseClasspathReader.readClasspathEntries(loc);
            for (EclipseClasspathEntry entry : entries)
            {
                projectHandler.handleEntry(entry);
                if (entry.isSubprojectEntry() && visitedEntries.contains(entry) == false)
                {
                    visitedEntries.add(entry);
                    traverse(projectHandler.createHandler(entry));
                }
            }
        }
        projectHandler.handleOnLeaving();
        
    }
}
