/*
 * Copyright 2007 ETH Zuerich, CISD
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ch.systemsx.cisd.dbmigration;

import java.io.File;

/**
 * Classes that implement this interface encapsulate mass uploading of tabular files to the database. The files to be
 * processed by implementations of this class are supposed to be <code>csv</code> files that can be uploaded to
 * exactly one table. They need to follow the naming convention <code><i>&lt;orderSpecifier&gt;</i>=<i>&lt;tableName&gt;</i>.csv</code>. 
 * Here the order specifier ensures that the dependency is right while the table name is the name of the table to upload the data
 * to.
 * 
 * @author Bernd Rinn
 */
public interface IMassUploader
{

    /**
     * Upload the data from file <var>massUploadFile</var> to the database.
     * 
     * @param massUploadFile File to upload to the database, following the naming convention
     *            <code>orderSpecifier=tableName.csv</code>.
     */
    public void performMassUpload(File massUploadFile);

}
